@@ -1,12 +1,21 @@
 """Constants for the Salus iT600 smart devices."""
 
-# Temperature units
-TEMP_CELSIUS = "°C"
+# Degree units
+DEGREE = "°"
 
-# Supported features
+# Temperature units
+TEMP_CELSIUS = f"{DEGREE}C"
+
+# States
+STATE_UNKNOWN = "unknown"
+
+# Supported climate features
 SUPPORT_TARGET_TEMPERATURE = 1
 SUPPORT_PRESET_MODE = 16
 
+# Supported cover features
+SUPPORT_SET_POSITION = 4
+
 # HVAC modes
 HVAC_MODE_OFF = "off"
 HVAC_MODE_HEAT = "heat"
